# Leonhard
A commons library for Project Euler problems.

## Installation
`pip install leonhard`

## Usage
```python
>>> from leonhard import leonhard
>>> print(leonhard.get_factors_of_positive_integer(10))
[1, 2, 5, 10]
```

## Functionalities
* `get_factors_of_positive_integer`: Gets the factors of a given positive integer
* `generate_fibonacci_sequence`: Generates a Fibonacci sequence
* `is_prime`: Checks if a number is prime or not
* `is_pythagorean_triplet`: Checks if a^2 + b^2 = c^2 where a < b < c
* `count_digits`: Counts the number of digits of a given number
* `generate_collatz_sequence`: Generates a collatz sequence
* `generate_cyclic_permutation`: Generates the list of cyclic permutation of a given number
* `is_triangle_number()`: Checks if a number is triangular or not

## Samples
Sample files are found in `samples/`


